<?php

namespace Chemical\Seller\Policies;

use Litepie\User\Contracts\UserPolicy;
use Chemical\Seller\Models\Distributor;

class DistributorPolicy
{

    /**
     * Determine if the given user can view the distributor.
     *
     * @param UserPolicy $user
     * @param Distributor $distributor
     *
     * @return bool
     */
    public function view(UserPolicy $user, Distributor $distributor)
    {
        if ($user->canDo('seller.distributor.view') && $user->isAdmin()) {
            return true;
        }

        return $distributor->user_id == user_id() && $distributor->user_type == user_type();
    }

    /**
     * Determine if the given user can create a distributor.
     *
     * @param UserPolicy $user
     * @param Distributor $distributor
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('seller.distributor.create');
    }

    /**
     * Determine if the given user can update the given distributor.
     *
     * @param UserPolicy $user
     * @param Distributor $distributor
     *
     * @return bool
     */
    public function update(UserPolicy $user, Distributor $distributor)
    {
        if ($user->canDo('seller.distributor.edit') && $user->isAdmin()) {
            return true;
        }

        return $distributor->user_id == user_id() && $distributor->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given distributor.
     *
     * @param UserPolicy $user
     * @param Distributor $distributor
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Distributor $distributor)
    {
        return $distributor->user_id == user_id() && $distributor->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given distributor.
     *
     * @param UserPolicy $user
     * @param Distributor $distributor
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Distributor $distributor)
    {
        if ($user->canDo('seller.distributor.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given distributor.
     *
     * @param UserPolicy $user
     * @param Distributor $distributor
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Distributor $distributor)
    {
        if ($user->canDo('seller.distributor.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
