<?php

namespace Chemical\Seller\Policies;

use Litepie\User\Contracts\UserPolicy;
use Chemical\Seller\Models\Place;

class PlacePolicy
{

    /**
     * Determine if the given user can view the place.
     *
     * @param UserPolicy $user
     * @param Place $place
     *
     * @return bool
     */
    public function view(UserPolicy $user, Place $place)
    {
        if ($user->canDo('seller.place.view') && $user->isAdmin()) {
            return true;
        }

        return $place->user_id == user_id() && $place->user_type == user_type();
    }

    /**
     * Determine if the given user can create a place.
     *
     * @param UserPolicy $user
     * @param Place $place
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('seller.place.create');
    }

    /**
     * Determine if the given user can update the given place.
     *
     * @param UserPolicy $user
     * @param Place $place
     *
     * @return bool
     */
    public function update(UserPolicy $user, Place $place)
    {
        if ($user->canDo('seller.place.edit') && $user->isAdmin()) {
            return true;
        }

        return $place->user_id == user_id() && $place->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given place.
     *
     * @param UserPolicy $user
     * @param Place $place
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Place $place)
    {
        return $place->user_id == user_id() && $place->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given place.
     *
     * @param UserPolicy $user
     * @param Place $place
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Place $place)
    {
        if ($user->canDo('seller.place.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given place.
     *
     * @param UserPolicy $user
     * @param Place $place
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Place $place)
    {
        if ($user->canDo('seller.place.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
