<?php

namespace Chemical\Seller\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Chemical\Seller\Models\Seller;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Chemical\Seller\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/seller/place/*')) {
            Route::bind('place', function ($place) {
                $placerepo = $this->app->make('Chemical\Seller\Interfaces\PlaceRepositoryInterface');
                return $placerepo->findorNew($place);
            });
        }

        if (Request::is('*/seller/distributor/*')) {
            Route::bind('distributor', function ($distributor) {
                $distributorrepo = $this->app->make('Chemical\Seller\Interfaces\DistributorRepositoryInterface');
                return $distributorrepo->findorNew($distributor);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
