<?php

namespace Chemical\Seller\Providers;

use Illuminate\Support\ServiceProvider;

class SellerServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'seller');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'seller');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerSeller();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerSeller()
    {
        $this->app->bind('seller', function($app) {
            return new Seller($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Seller', 'Lavalite\Seller\Facades\Seller');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('chemical.seller', function ($app) {
            return $this->app->make('Chemical\Seller\Seller');
        });

        // Bind Place to repository
        $this->app->bind(
            'Chemical\Seller\Interfaces\PlaceRepositoryInterface',
            \Chemical\Seller\Repositories\Eloquent\PlaceRepository::class
        );
        // Bind Distributor to repository
        $this->app->bind(
            'Chemical\Seller\Interfaces\DistributorRepositoryInterface',
            \Chemical\Seller\Repositories\Eloquent\DistributorRepository::class
        );

        $this->app->register(\Chemical\Seller\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Chemical\Seller\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and seller's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/seller.php', 'seller'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeSeller::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['chemical.seller'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('chemical/seller.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/seller')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/seller')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
